@@ -734,10 +734,6 @@ c.bitwhich <- function(...){
 #! \keyword{ classes }
 #! \keyword{ logic }
 
-as.bit <- function(x, ...){
-  UseMethod("as.bit", x)
-}
-
 as.bit.bit <- function(x, ...)
   x
 
@@ -942,9 +938,6 @@ as.double.ri <- function(x, ...){
 
 
 
-as.which <- function (x, ...)
-  UseMethod("as.which")
-
 as.which.default <- function(x, ...){
   ret <- which(x)
   class(ret) <- "which"
@@ -1039,9 +1032,6 @@ as.which.bitwhich <- function(x, ...){
 #! \keyword{ classes }
 #! \keyword{ logic }
 
-as.bitwhich <- function(x, ...)
-UseMethod("as.bitwhich")
-
 as.bitwhich.bitwhich <- function(x, ...){
   x
 }
@@ -1320,10 +1310,6 @@ as.logical.bitwhich <- function(x, ...){
   .Call("R_bit_or", e1, e2, ret, PACKAGE="bit")
 }
 
-xor <- function(x, y){
-  UseMethod("xor", x)
-}
-
 xor.default <- function(x,y){
   as.logical(x) != as.logical(y)
 }
@@ -2201,12 +2187,6 @@ summary.ri <- function(object, ...){
 #! \keyword{ attribute }
 
 
-physical <- function(x)UseMethod("physical")
-"physical<-" <- function(x, value)UseMethod("physical<-")
-
-virtual <- function(x)UseMethod("virtual")
-"virtual<-" <- function(x, value)UseMethod("virtual<-")
-
 # this version without vmode() will be overwritte by the version in package ff
 physical.default <- function(x){
   p <- attributes(attr(x, "physical"))
